#!/usr/bin/python3
# -*- coding: utf-8 -*-

import sys
import gi
gi.require_version('Gtk','3.0')
from gi.repository import Gtk, Gio, GLib, GObject, Gdk
from gi.repository.GdkPixbuf import Pixbuf
gi.require_version('WebKit2', '4.0')
from gi.repository import WebKit2 as webkit
ICON = "/usr/share/pixmaps/lemurae.svg"

class Lemurae(object):

    def __init__(self):
        xml = Gtk.Builder()
        xml.add_from_file("/usr/share/lemurae/lemurae.glade")
        #xml.signal_autoconnect(self)

        # Widgets
        self.word = xml.get_object("Palabra")
        self.frame = xml.get_object("Marco")
        self.appw = xml.get_object("appw")
        self.back_button = xml.get_object("bAtras")
        self.next_button = xml.get_object("bAdelante")
        self.buscar_button = xml.get_object("bBuscar")
        self.statusbar = xml.get_object("statusbar")
        self.exit_button = xml.get_object("bSalir")
        self.help_button = xml.get_object("bAyuda")
        self.web_control = webkit.WebView()
        self.__set_widgets()


        self.appw.show_all()
        self.is_showed = True


    def __set_widgets(self):
        # Set buttons sensitive
        self.back_button.set_sensitive(False)
        self.next_button.set_sensitive(False)

        # Set web_control
        #self.web_control.connect('load-finished', self.__on_net_stop)
        #self.web_control.connect('load-started', self.__on_net_start)
        self.web_control.connect('load-changed', self.__on_load_changed)
        self.web_control.show_all()
        self.statusbar.push(0, "Listo.")
        self.exit_button.connect('clicked', self.on_exit_clicked)
        self.buscar_button.connect('clicked', self.on_bBuscar_clicked)
        self.help_button.connect('clicked', self.on_bAyuda_clicked)
        self.back_button.connect('clicked', self.on_bAtras_clicked)
        self.next_button.connect('clicked', self.on_bAdelante_clicked)
        # Add web_control
        self.scrolled_window = Gtk.ScrolledWindow()
        self.scrolled_window.add(self.web_control)
        self.frame.add(self.scrolled_window)
        self.appw.connect("destroy", self.on_appw_destroy)
        self.word.connect("activate", self.on_bBuscar_clicked)
        

        # App icon
        icon = Pixbuf.new_from_file(ICON)
        self.appw.set_icon(icon)


    # SIGNAL HANDLERS ##############################
    def __on_load_changed (self, webview, event):
        
        finished=webkit.LoadEvent.FINISHED
        started=webkit.LoadEvent.STARTED
        
        if event == finished:
            self.__on_net_stop()
        if event == started:
            self.__on_net_start()

    def on_bBuscar_clicked(self, widget):
        url = "http://dle.rae.es/?w="
        url += self.word.get_text().lower()
        self.web_control.load_uri(url)
        self.word.select_region(0, len(self.word.get_text()))
        self.appw.set_focus(self.word)

    def on_bAdelante_clicked(self, widget):
        self.web_control.go_forward()

    def on_bAtras_clicked(self, widget):
        self.web_control.go_back()

    def on_bAyuda_clicked(self, object):
        dlg = Gtk.AboutDialog()
        logo = Pixbuf.new_from_file(ICON)

        dlg.set_program_name("Lemurae")
        dlg.set_version("0.2.2")
        dlg.set_logo(logo)
        dlg.connect("response", self.on_close)
        dlg.show()
        
    def on_close(self, action, parameter):
        action.destroy()

    def on_exit_clicked(self, widget):
        Gtk.main_quit()
        sys.exit(0)

    def on_appw_delete_event(self, widget, event):
        Gtk.main_quit()
        sys.exit(0)

    def __on_net_start(self, *args):
        self.statusbar.push(0, "Buscando...")

    def __on_net_stop(self, *args):
        self.statusbar.pop(0)
        self.back_button.set_sensitive(self.web_control.can_go_back())
        self.next_button.set_sensitive(self.web_control.can_go_forward())
        self.appw.set_focus(self.word)

    def show_window(self):
        self.appw.show_all()
        self.is_showed = True

    def hide_window(self):
        self.appw.hide()
        self.is_showed = False
    
    def on_appw_destroy(self, *args):
        Gtk.main_quit()
        sys.exit(0)

if __name__ == "__main__":
    Lemurae()	
    Gtk.main()
